Perfect Swing

# *Course Closed – Latest Update 1/2/10*

# Perfect Swing Return to Connecticut page

845 Sullivan Ave
South Windsor, CT 06074-2047
(860) 664-1001 Other Activities: Ice cream, batting cages

## Cost: $5.50

## Par: None listed

2007 Ratings 2011 Ratings

Difficulty: 4 Difficulty: 7

Creativity: 2 Creativity: 8

Atmosphere: 8 Atmosphere: 8

Perfect Swing must be named for its batting cages considering no one’s really taking swings in mini golf. The Putting Penguin played this course on a beautiful sunny Sunday in early May, and we were the only people there! Really it was a shame because it was a good course. We hope they get a website running or do some more advertising.

This course looks like many other tournament-style courses. Most of the holes were a variation of a curve and some type of bump in the course. It looks pretty generic. So did the score card. It has no course name on it or the par for each hole. The cups were a little too shallow on the front nine, and the ball hopped out on a number of occasions. There are flags in the cup at each hole, which is a minor annoyance because you have to remove and replace them throughout play. The water wasn’t running, but it was early in the season. Hole 13 was a 3 tiered hole and was neat except for the pvc pipe that was a little beat up and didn’t allow you to get the ball in the hole at the bottom. There were some small lumps in the mats on the back nine that we weren’t sure if they were purposeful or a problem with the mats, but they didn’t seem to interfere too much with the movement of the ball.

Despite these criticisms we enjoyed this course. The layout and vegetation looked great, and the course was well maintained. Considering how prices have been going up for miniature golf we thought the $5.50 was quite reasonable. The location is great; it’s just down the street from the Buckland Hills Mall and Evergreen Walk. We would recommend this course to everyone. They even have Gifford’s ice cream!

2011 Update

It has been four years since we have reviewed Perfect Swing, and right off the bat we have to say it is well worth the visit if you live in the South Windsor area. It hasn’t even changed its price!

One noticeable difference between our review in 2007 and our update is that we have changed the Creativity score quite a bit. After playing over 100 courses, we have to admit that there are hole designs at Perfect Swing that we have never seen any other courses. We also noticed this time that the “variation of a curve and some type of bump in the course” appear to be purposeful. If someone were to play this course a few times it would be possible to putt along these curves and bumps and make an easy 2 or even an ace. We’re thinking we must not have had that kind of appreciation for the course the first time we played there.

We still don’t like the rubber starting mats, but the course no longer has the flags in the cups, which we’re happy about. Unfortunately, now there are no hole numbers on the course so a player needs to pay attention while keeping score on the score card. The scorecards themselves are still generic with no pars listed, some of the cups are still too shallow, some of the carpets need a little work, and the pvc pipe on hole 13 is still beat up. But on a positive note, the landscaping is still excellently maintained, and there’s a lot of space between the holes.

The Putting Penguin still highly recommends this course!

Reviewed by Pat, Mandy and Putt

Reviewed in 2007 & 2011

Visitor Review #1

REVIEW IT

Course Pictures (click to enlarge)

You can also see pictures of all 18 holes on our Flickr Page

Map

View Larger Map

Visitor Review #1 (2018)

###

Price: $5

Par: 41

Difficulty: 3

Creativity: 3

Atmosphere: 2

This course was wonderfully reviewed in the past but seems to have fallen into disrepair & neglect. It was early in the season but water features were not on, holes were not numbered & carpeting was not well maintained.

Reviewed by Glenda R

Reviewed in 2018